@@ -3,6 +3,10 @@
 from dask import array as da
 
 from ..fix import Fix
+from .cesm1_cam5 import Cl as BaseCl
+
+
+Cl = BaseCl
 
 
 class Gpp(Fix):
