@@ -47,6 +47,10 @@ class DerivedVariable(DerivedVariableBase):
         project = clwvi_cube.attributes.get('project_id')
         if project:
             dataset = clwvi_cube.attributes.get('model_id')
+            # some CMIP6 models define both, project_id and source_id but
+            # no model_id --> also try source_id to find model name
+            if not dataset:
+                dataset = clwvi_cube.attributes.get('source_id')
         else:
             project = clwvi_cube.attributes.get('mip_era')
             dataset = clwvi_cube.attributes.get('source_id')
@@ -55,26 +59,33 @@ class DerivedVariable(DerivedVariableBase):
         # cubes?
 
         bad_datasets = [
+            'CCSM4',           # CMIP5 models
             'CESM1-CAM5-1-FV2',
             'CESM1-CAM5',
             'CMCC-CESM',
             'CMCC-CM',
             'CMCC-CMS',
+            'CSIRO-Mk3-6-0',
+            'GISS-E2-1-G',
+            'GISS-E2-1-H',
             'IPSL-CM5A-MR',
             'IPSL-CM5A-LR',
             'IPSL-CM5B-LR',
-            'CCSM4',
             'IPSL-CM5A-MR',
             'MIROC-ESM',
             'MIROC-ESM-CHEM',
             'MIROC-ESM',
-            'CSIRO-Mk3-6-0',
-            'MPI-ESM-MR',
             'MPI-ESM-LR',
+            'MPI-ESM-MR',
             'MPI-ESM-P',
+            'AWI-ESM-1-1-LR',   # CMIP6 models
             'CAMS-CSM1-0',
-            'GISS-E2-1-G',
-            'GISS-E2-1-H',
+            'FGOALS-f3-L',
+            'IPSL-CM6A-LR',
+            'MPI-ESM-1-2-HAM',
+            'MPI-ESM1-2-HR',
+            'MPI-ESM1-2-LR',
+            'SAM0-UNICON'
         ]
         affected_projects = ["CMIP5", "CMIP5_ETHZ", "CMIP6"]
         if (project in affected_projects and dataset in bad_datasets):
