@@ -539,6 +539,7 @@ def climate_statistics(cube,
     iris.cube.Cube
         Monthly statistics cube
     """
+    original_dtype = cube.dtype
     period = period.lower()
 
     if period in ('full', ):
@@ -547,25 +548,32 @@ def climate_statistics(cube,
             time_weights = get_time_weights(cube)
             if time_weights.min() == time_weights.max():
                 # No weighting needed.
-                cube = cube.collapsed('time', operator_method)
+                clim_cube = cube.collapsed('time', operator_method)
             else:
-                cube = cube.collapsed('time',
-                                      operator_method,
-                                      weights=time_weights)
+                clim_cube = cube.collapsed('time',
+                                           operator_method,
+                                           weights=time_weights)
         else:
-            cube = cube.collapsed('time', operator_method)
-        return cube
-
-    clim_coord = _get_period_coord(cube, period, seasons)
-    operator = get_iris_analysis_operation(operator)
-    clim_cube = cube.aggregated_by(clim_coord, operator)
-    clim_cube.remove_coord('time')
-    if clim_cube.coord(clim_coord.name()).is_monotonic():
-        iris.util.promote_aux_coord_to_dim_coord(clim_cube, clim_coord.name())
+            clim_cube = cube.collapsed('time', operator_method)
     else:
-        clim_cube = iris.cube.CubeList(clim_cube.slices_over(
-            clim_coord.name())).merge_cube()
-    cube.remove_coord(clim_coord)
+        clim_coord = _get_period_coord(cube, period, seasons)
+        operator = get_iris_analysis_operation(operator)
+        clim_cube = cube.aggregated_by(clim_coord, operator)
+        clim_cube.remove_coord('time')
+        if clim_cube.coord(clim_coord.name()).is_monotonic():
+            iris.util.promote_aux_coord_to_dim_coord(clim_cube,
+                                                     clim_coord.name())
+        else:
+            clim_cube = iris.cube.CubeList(
+                clim_cube.slices_over(clim_coord.name())).merge_cube()
+        cube.remove_coord(clim_coord)
+
+    new_dtype = clim_cube.dtype
+    if original_dtype != new_dtype:
+        logger.warning(
+            "climate_statistics changed dtype from "
+            "%s to %s, changing back", original_dtype, new_dtype)
+        clim_cube.data = clim_cube.core_data().astype(original_dtype)
     return clim_cube
 
 
