@@ -1,8 +1,10 @@
 """Tests for the fixes of GFDL-CM4."""
 import iris
 import numpy as np
+import pytest
 
-from esmvalcore.cmor._fixes.cmip6.gfdl_cm4 import Cl, Cli, Clw
+from esmvalcore.cmor._fixes.cmip6.gfdl_cm4 import Cl, Cli, Clw, Siconc
+from esmvalcore.cmor._fixes.common import SiconcFixScalarCoord
 from esmvalcore.cmor.fix import Fix
 from esmvalcore.cmor.table import get_var_info
 
@@ -33,6 +35,7 @@ AIR_PRESSURE_BOUNDS = np.array([[[[[0.0, 1.5],
                                    [9.0, 21.0]]]]])
 
 
+@pytest.mark.sequential
 def test_cl_fix_metadata(test_data_path):
     """Test ``fix_metadata`` for ``cl``."""
     nc_path = test_data_path / 'gfdl_cm4_cl.nc'
@@ -88,3 +91,14 @@ def test_get_clw_fix():
 def test_clw_fix():
     """Test fix for ``clw``."""
     assert Clw is Cl
+
+
+def test_get_siconc_fix():
+    """Test getting of fix."""
+    fix = Fix.get_fixes('CMIP6', 'GFDL-CM4', 'SImon', 'siconc')
+    assert fix == [Siconc(None)]
+
+
+def test_siconc_fix():
+    """Test fix for ``siconc``."""
+    assert Siconc is SiconcFixScalarCoord
