@@ -10,7 +10,6 @@ import yaml
 from PIL import Image
 
 import esmvalcore
-from esmvalcore import __version__ as current_version
 from esmvalcore._config import TAGS
 from esmvalcore._recipe import TASKSEP, read_recipe_file
 from esmvalcore._recipe_checks import RecipeError
@@ -296,6 +295,10 @@ def patched_failing_datafinder(tmp_path, monkeypatch):
                 return []
             if 'sftlf' in filename:
                 return []
+            if 'IyrAnt_' in filename:
+                return []
+            if 'IyrGre_' in filename:
+                return []
         return _get_filenames(tmp_path, filenames, tracking_id)
 
     monkeypatch.setattr(esmvalcore._data_finder, 'find_files', find_files)
@@ -2010,8 +2013,8 @@ def test_user_defined_fxvar(tmp_path, patched_datafinder, config_user):
     settings = product.settings['mask_landseaice']
     assert len(settings) == 1
     assert settings['mask_out'] == 'sea'
-    assert '_fx_' in fx_variables['sftlf']['filename']
-    assert '_piControl_' in fx_variables['sftlf']['filename']
+    assert '_fx_' in fx_variables['sftgif']['filename']
+    assert '_piControl_' in fx_variables['sftgif']['filename']
 
     # volume statistics
     settings = product.settings['volume_statistics']
@@ -2143,10 +2146,139 @@ def test_landmask_no_fx(tmp_path, patched_failing_datafinder, config_user):
         assert not any(fx_variables)
 
 
-# TODO remove after fixing test below
-def test_fx_vars_mip_change_cmip6_incomplete(tmp_path,
-                                             patched_datafinder,
-                                             config_user):
+def test_fx_vars_fixed_mip_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test fx variables with given mips."""
+    TAGS.set_tag_values(TAGS_FOR_TESTING)
+
+    content = dedent("""
+        preprocessors:
+          preproc:
+           area_statistics:
+             operator: mean
+             fx_variables:
+               sftgif:
+                 mip: fx
+               volcello:
+                 ensemble: r2i1p1f1
+                 mip: Ofx
+
+        diagnostics:
+          diagnostic_name:
+            variables:
+              tas:
+                preprocessor: preproc
+                project: CMIP6
+                mip: Amon
+                exp: historical
+                start_year: 2000
+                end_year: 2005
+                ensemble: r1i1p1f1
+                grid: gn
+                additional_datasets:
+                  - {dataset: CanESM5}
+            scripts: null
+        """)
+    recipe = get_recipe(tmp_path, content, config_user)
+
+    # Check generated tasks
+    assert len(recipe.tasks) == 1
+    task = recipe.tasks.pop()
+    assert task.name == 'diagnostic_name' + TASKSEP + 'tas'
+    assert len(task.products) == 1
+    product = task.products.pop()
+
+    # Check area_statistics
+    assert 'area_statistics' in product.settings
+    settings = product.settings['area_statistics']
+    assert len(settings) == 1
+    assert settings['operator'] == 'mean'
+
+    # Check add_fx_variables
+    fx_variables = product.settings['add_fx_variables']['fx_variables']
+    assert isinstance(fx_variables, dict)
+    assert len(fx_variables) == 2
+    assert '_fx_' in fx_variables['sftgif']['filename']
+    assert '_r2i1p1f1_' in fx_variables['volcello']['filename']
+    assert '_Ofx_' in fx_variables['volcello']['filename']
+
+
+def test_fx_vars_invalid_mip_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test fx variables with invalid mip."""
+    TAGS.set_tag_values(TAGS_FOR_TESTING)
+
+    content = dedent("""
+        preprocessors:
+          preproc:
+           area_statistics:
+             operator: mean
+             fx_variables:
+               areacella:
+                 mip: INVALID
+
+        diagnostics:
+          diagnostic_name:
+            variables:
+              tas:
+                preprocessor: preproc
+                project: CMIP6
+                mip: Amon
+                exp: historical
+                start_year: 2000
+                end_year: 2005
+                ensemble: r1i1p1f1
+                grid: gn
+                additional_datasets:
+                  - {dataset: CanESM5}
+            scripts: null
+        """)
+    msg = ("Requested mip table 'INVALID' for fx variable 'areacella' not "
+           "available for project 'CMIP6'")
+    with pytest.raises(RecipeError) as rec_err_exp:
+        get_recipe(tmp_path, content, config_user)
+    assert str(rec_err_exp.value) == INITIALIZATION_ERROR_MSG
+    assert msg in rec_err_exp.value.failed_tasks[0].message
+
+
+def test_fx_vars_invalid_mip_for_var_cmip6(tmp_path, patched_datafinder,
+                                           config_user):
+    """Test fx variables with invalid mip for variable."""
+    TAGS.set_tag_values(TAGS_FOR_TESTING)
+
+    content = dedent("""
+        preprocessors:
+          preproc:
+           area_statistics:
+             operator: mean
+             fx_variables:
+               areacella:
+                 mip: Lmon
+
+        diagnostics:
+          diagnostic_name:
+            variables:
+              tas:
+                preprocessor: preproc
+                project: CMIP6
+                mip: Amon
+                exp: historical
+                start_year: 2000
+                end_year: 2005
+                ensemble: r1i1p1f1
+                grid: gn
+                additional_datasets:
+                  - {dataset: CanESM5}
+            scripts: null
+        """)
+    msg = ("fx variable 'areacella' not available in CMOR table 'Lmon' for "
+           "'CMIP6'")
+    with pytest.raises(RecipeError) as rec_err_exp:
+        get_recipe(tmp_path, content, config_user)
+    assert str(rec_err_exp.value) == INITIALIZATION_ERROR_MSG
+    assert msg in rec_err_exp.value.failed_tasks[0].message
+
+
+def test_fx_vars_mip_search_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test mip tables search for different fx variables."""
     TAGS.set_tag_values(TAGS_FOR_TESTING)
 
     content = dedent("""
@@ -2156,13 +2288,8 @@ def test_fx_vars_mip_change_cmip6_incomplete(tmp_path,
              operator: mean
              fx_variables:
                areacella:
-                 ensemble: r2i1p1f1
                areacello:
                clayfrac:
-               sftlf:
-               sftgif:
-                 mip: fx
-               sftof:
            mask_landsea:
              mask_out: sea
 
@@ -2196,15 +2323,6 @@ def test_fx_vars_mip_change_cmip6_incomplete(tmp_path,
     settings = product.settings['area_statistics']
     assert len(settings) == 1
     assert settings['operator'] == 'mean'
-    fx_variables = product.settings['add_fx_variables']['fx_variables']
-    assert isinstance(fx_variables, dict)
-    assert len(fx_variables) == 6
-    assert '_fx_' in fx_variables['areacella']['filename']
-    assert '_r2i1p1f1_' in fx_variables['areacella']['filename']
-    assert '_Ofx_' in fx_variables['areacello']['filename']
-    assert '_Efx_' in fx_variables['clayfrac']['filename']
-    assert '_fx_' in fx_variables['sftlf']['filename']
-    assert '_Ofx_' in fx_variables['sftof']['filename']
 
     # Check mask_landsea
     assert 'mask_landsea' in product.settings
@@ -2212,81 +2330,19 @@ def test_fx_vars_mip_change_cmip6_incomplete(tmp_path,
     assert len(settings) == 1
     assert settings['mask_out'] == 'sea'
 
-
-@pytest.mark.skipif(current_version < "2.4.0",
-                    reason="github.com/ESMValGroup/ESMValCore/issues/1159")
-def test_fx_vars_mip_change_cmip6(tmp_path, patched_datafinder, config_user):
-    TAGS.set_tag_values(TAGS_FOR_TESTING)
-
-    content = dedent("""
-        preprocessors:
-          preproc:
-           area_statistics:
-             operator: mean
-             fx_variables:
-               areacella:
-                 ensemble: r2i1p1f1
-               areacello:
-               clayfrac:
-               sftlf:
-               sftgif:
-                 mip: fx
-               sftof:
-           mask_landsea:
-             mask_out: sea
-
-        diagnostics:
-          diagnostic_name:
-            variables:
-              tas:
-                preprocessor: preproc
-                project: CMIP6
-                mip: Amon
-                exp: historical
-                start_year: 2000
-                end_year: 2005
-                ensemble: r1i1p1f1
-                grid: gn
-                additional_datasets:
-                  - {dataset: CanESM5}
-            scripts: null
-        """)
-    recipe = get_recipe(tmp_path, content, config_user)
-
-    # Check generated tasks
-    assert len(recipe.tasks) == 1
-    task = recipe.tasks.pop()
-    assert task.name == 'diagnostic_name' + TASKSEP + 'tas'
-    assert len(task.products) == 1
-    product = task.products.pop()
-
-    # Check area_statistics
-    assert 'area_statistics' in product.settings
-    settings = product.settings['area_statistics']
-    assert len(settings) == 1
-    assert settings['operator'] == 'mean'
+    # Check add_fx_variables
     fx_variables = product.settings['add_fx_variables']['fx_variables']
     assert isinstance(fx_variables, dict)
-    assert len(fx_variables) == 6
+    assert len(fx_variables) == 5
     assert '_fx_' in fx_variables['areacella']['filename']
-    assert '_r2i1p1f1_' in fx_variables['areacella']['filename']
     assert '_Ofx_' in fx_variables['areacello']['filename']
     assert '_Efx_' in fx_variables['clayfrac']['filename']
     assert '_fx_' in fx_variables['sftlf']['filename']
-    assert '_fx_' in fx_variables['sftgif']['filename']  # fails, see skipif
     assert '_Ofx_' in fx_variables['sftof']['filename']
 
-    # Check mask_landsea
-    assert 'mask_landsea' in product.settings
-    settings = product.settings['mask_landsea']
-    assert len(settings) == 1
-    assert settings['mask_out'] == 'sea'
 
-
-# TODO remove when you fix test below
-def test_fx_list_mip_change_cmip6_incomplete(tmp_path,
-                                             patched_datafinder,
-                                             config_user):
+def test_fx_list_mip_search_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test mip tables search for list of different fx variables."""
     content = dedent("""
         preprocessors:
           preproc:
@@ -2297,11 +2353,8 @@ def test_fx_list_mip_change_cmip6_incomplete(tmp_path,
                'areacello',
                'clayfrac',
                'sftlf',
-               'sftgif',
                'sftof',
                ]
-           mask_landsea:
-             mask_out: sea
 
         diagnostics:
           diagnostic_name:
@@ -2333,87 +2386,17 @@ def test_fx_list_mip_change_cmip6_incomplete(tmp_path,
     settings = product.settings['area_statistics']
     assert len(settings) == 1
     assert settings['operator'] == 'mean'
+
+    # Check add_fx_variables
     fx_variables = product.settings['add_fx_variables']['fx_variables']
     assert isinstance(fx_variables, dict)
-    assert len(fx_variables) == 6
+    assert len(fx_variables) == 5
     assert '_fx_' in fx_variables['areacella']['filename']
     assert '_Ofx_' in fx_variables['areacello']['filename']
     assert '_Efx_' in fx_variables['clayfrac']['filename']
     assert '_fx_' in fx_variables['sftlf']['filename']
     assert '_Ofx_' in fx_variables['sftof']['filename']
 
-    # Check mask_landsea
-    assert 'mask_landsea' in product.settings
-    settings = product.settings['mask_landsea']
-    assert len(settings) == 1
-    assert settings['mask_out'] == 'sea'
-
-
-@pytest.mark.skipif(current_version < "2.4.0",
-                    reason="github.com/ESMValGroup/ESMValCore/issues/1159")
-def test_fx_list_mip_change_cmip6(tmp_path, patched_datafinder, config_user):
-    content = dedent("""
-        preprocessors:
-          preproc:
-           area_statistics:
-             operator: mean
-             fx_variables: [
-               'areacella',
-               'areacello',
-               'clayfrac',
-               'sftlf',
-               'sftgif',
-               'sftof',
-               ]
-           mask_landsea:
-             mask_out: sea
-
-        diagnostics:
-          diagnostic_name:
-            variables:
-              tas:
-                preprocessor: preproc
-                project: CMIP6
-                mip: Amon
-                exp: historical
-                start_year: 2000
-                end_year: 2005
-                ensemble: r1i1p1f1
-                grid: gn
-                additional_datasets:
-                  - {dataset: CanESM5}
-            scripts: null
-        """)
-    recipe = get_recipe(tmp_path, content, config_user)
-
-    # Check generated tasks
-    assert len(recipe.tasks) == 1
-    task = recipe.tasks.pop()
-    assert task.name == 'diagnostic_name' + TASKSEP + 'tas'
-    assert len(task.products) == 1
-    product = task.products.pop()
-
-    # Check area_statistics
-    assert 'area_statistics' in product.settings
-    settings = product.settings['area_statistics']
-    assert len(settings) == 1
-    assert settings['operator'] == 'mean'
-    fx_variables = product.settings['add_fx_variables']['fx_variables']
-    assert isinstance(fx_variables, dict)
-    assert len(fx_variables) == 6
-    assert '_fx_' in fx_variables['areacella']['filename']
-    assert '_Ofx_' in fx_variables['areacello']['filename']
-    assert '_Efx_' in fx_variables['clayfrac']['filename']
-    assert '_fx_' in fx_variables['sftlf']['filename']
-    assert '_fx_' in fx_variables['sftgif']['filename']  # fails, see skipif
-    assert '_Ofx_' in fx_variables['sftof']['filename']
-
-    # Check mask_landsea
-    assert 'mask_landsea' in product.settings
-    settings = product.settings['mask_landsea']
-    assert len(settings) == 1
-    assert settings['mask_out'] == 'sea'
-
 
 def test_fx_vars_volcello_in_ofx_cmip6(tmp_path, patched_datafinder,
                                        config_user):
@@ -2743,6 +2726,7 @@ def test_wrong_project(tmp_path, patched_datafinder, config_user):
 
 
 def test_invalid_fx_var_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test that error is raised for invalid fx variable."""
     TAGS.set_tag_values(TAGS_FOR_TESTING)
 
     content = dedent("""
@@ -2778,6 +2762,100 @@ def test_invalid_fx_var_cmip6(tmp_path, patched_datafinder, config_user):
     assert msg in rec_err_exp.value.failed_tasks[0].message
 
 
+def test_ambiguous_fx_var_cmip6(tmp_path, patched_datafinder, config_user):
+    """Test that error is raised for fx files available in multiple mips."""
+    TAGS.set_tag_values(TAGS_FOR_TESTING)
+
+    content = dedent("""
+        preprocessors:
+          preproc:
+           area_statistics:
+             operator: mean
+             fx_variables:
+               volcello:
+
+        diagnostics:
+          diagnostic_name:
+            variables:
+              tas:
+                preprocessor: preproc
+                project: CMIP6
+                mip: Amon
+                exp: historical
+                start_year: 2000
+                end_year: 2005
+                ensemble: r1i1p1f1
+                grid: gn
+                additional_datasets:
+                  - {dataset: CanESM5}
+            scripts: null
+        """)
+    msg = ("Requested fx variable 'volcello' for dataset 'CanESM5' of project "
+           "'CMIP6' is available in more than one CMOR table for 'CMIP6': "
+           "['Odec', 'Ofx', 'Omon', 'Oyr']")
+    with pytest.raises(RecipeError) as rec_err_exp:
+        get_recipe(tmp_path, content, config_user)
+    assert str(rec_err_exp.value) == INITIALIZATION_ERROR_MSG
+    assert msg in rec_err_exp.value.failed_tasks[0].message
+
+
+def test_unique_fx_var_in_multiple_mips_cmip6(tmp_path,
+                                              patched_failing_datafinder,
+                                              config_user):
+    """Test that no error is raised for fx files available in one mip."""
+    TAGS.set_tag_values(TAGS_FOR_TESTING)
+
+    content = dedent("""
+        preprocessors:
+          preproc:
+           area_statistics:
+             operator: mean
+             fx_variables:
+               sftgif:
+
+        diagnostics:
+          diagnostic_name:
+            variables:
+              tas:
+                preprocessor: preproc
+                project: CMIP6
+                mip: Amon
+                exp: historical
+                start_year: 2000
+                end_year: 2005
+                ensemble: r1i1p1f1
+                grid: gn
+                additional_datasets:
+                  - {dataset: CanESM5}
+            scripts: null
+        """)
+    recipe = get_recipe(tmp_path, content, config_user)
+
+    # Check generated tasks
+    assert len(recipe.tasks) == 1
+    task = recipe.tasks.pop()
+    assert task.name == 'diagnostic_name' + TASKSEP + 'tas'
+    assert len(task.products) == 1
+    product = task.products.pop()
+
+    # Check area_statistics
+    assert 'area_statistics' in product.settings
+    settings = product.settings['area_statistics']
+    assert len(settings) == 1
+    assert settings['operator'] == 'mean'
+
+    # Check add_fx_variables
+    # Due to failing datafinder, only files in LImon are found even though
+    # sftgif is available in the tables fx, IyrAnt, IyrGre and LImon
+    fx_variables = product.settings['add_fx_variables']['fx_variables']
+    assert isinstance(fx_variables, dict)
+    assert len(fx_variables) == 1
+    sftgif_files = fx_variables['sftgif']['filename']
+    assert isinstance(sftgif_files, list)
+    assert len(sftgif_files) == 1
+    assert'_LImon_' in sftgif_files[0]
+
+
 def test_multimodel_mask(tmp_path, patched_datafinder, config_user):
     """Test ``mask_multimodel``."""
     content = dedent("""
