@@ -1,3 +1,4 @@
+import multiprocessing
 import os
 from functools import partial
 from multiprocessing.pool import ThreadPool
@@ -8,28 +9,9 @@ import esmvalcore
 from esmvalcore._task import BaseTask, TaskSet
 
 
-@pytest.fixture
-def example_tasks():
-    """Example tasks for testing the task runners."""
-    tasks = TaskSet()
-    for i in range(3):
-        task = BaseTask(
-            name=f'task{i}',
-            ancestors=[
-                BaseTask(name=f'task{i}-ancestor{j}') for j in range(3)
-            ],
-        )
-        for task0 in task.flatten():
-            task0.priority = i
-        tasks.add(task)
-
-    return tasks
-
-
-@pytest.mark.parametrize('max_parallel_tasks', [1, 2, 3, 4, 16, None])
-def test_run_tasks(monkeypatch, tmp_path, max_parallel_tasks, example_tasks):
-    """Check that tasks are run correctly."""
+class MockBaseTask(BaseTask):
     def _run(self, input_files):
+        tmp_path = self._tmp_path
         output_file = tmp_path / self.name
 
         msg = ('running {} in thread {}, using input {}, generating {}'.format(
@@ -50,8 +32,33 @@ def test_run_tasks(monkeypatch, tmp_path, max_parallel_tasks, example_tasks):
 
         return [output_file]
 
-    monkeypatch.setattr(BaseTask, '_run', _run)
 
+@pytest.fixture
+def example_tasks(tmp_path):
+    """Example tasks for testing the task runners."""
+    tasks = TaskSet()
+    for i in range(3):
+        task = MockBaseTask(
+            name=f'task{i}',
+            ancestors=[
+                MockBaseTask(name=f'task{i}-ancestor{j}') for j in range(3)
+            ],
+        )
+        for task0 in task.flatten():
+            task0.priority = i
+            task0._tmp_path = tmp_path
+        tasks.add(task)
+
+    return tasks
+
+
+@pytest.mark.parametrize('mpmethod', ["spawn", "fork"])
+@pytest.mark.parametrize('max_parallel_tasks', [1, 2, 3, 4, 16, None])
+def test_run_tasks(monkeypatch, tmp_path, max_parallel_tasks, example_tasks,
+                   mpmethod):
+    """Check that tasks are run correctly."""
+    monkeypatch.setattr(esmvalcore._task, 'Pool',
+                        multiprocessing.get_context(mpmethod).Pool)
     example_tasks.run(max_parallel_tasks=max_parallel_tasks)
 
     for task in example_tasks:
@@ -72,7 +79,7 @@ def test_runner_uses_priority(monkeypatch, runner, example_tasks):
         order.append(self.priority)
         return [f'{self.name}_test.nc']
 
-    monkeypatch.setattr(BaseTask, '_run', _run)
+    monkeypatch.setattr(MockBaseTask, '_run', _run)
     monkeypatch.setattr(esmvalcore._task, 'Pool', ThreadPool)
 
     runner(example_tasks)
